@@ -162,6 +162,34 @@ EOT_`,
 			`[
   "b",
   "d",
+]`,
+		},
+		{
+			cty.TupleVal([]cty.Value{
+				cty.StringVal("boop\nbeep"),
+				cty.StringVal("b"),
+			}),
+			`[
+  <<-EOT
+  boop
+  beep
+  EOT
+  ,
+  "b",
+]`,
+		},
+		{
+			cty.TupleVal([]cty.Value{
+				cty.StringVal("b"),
+				cty.StringVal("boop\nbeep"),
+			}),
+			`[
+  "b",
+  <<-EOT
+  boop
+  beep
+  EOT
+  ,
 ]`,
 		},
 		{
